@@ -3,7 +3,7 @@ import asyncio
 import logging
 from dataclasses import dataclass, field
 
-from gi.repository import GLib as glib  # type: ignore
+from gi.repository import GLib as glib
 from datastreamservicelib.service import BaseService as DSLBaseService
 from datastreamservicelib.service import SimpleServiceMixin
 
@@ -25,7 +25,7 @@ class BaseService(DSLBaseService):
         async def wait_for_loop() -> None:
             """Wait for the loop to be running"""
             nonlocal self
-            while not self._gloop.is_running():
+            while not self._gloop.is_running():  # type: ignore
                 await asyncio.sleep(0.01)
 
         await asyncio.wait_for(wait_for_loop(), timeout=0.5)
