@@ -1,16 +1,16 @@
 """Widget baseclasses"""
 from typing import Any
 
-import gi  # type: ignore
+import gi
 
 gi.require_version("Gtk", "3.0")
 # pylint: disable=C0413
-from gi.repository import Gtk  # type: ignore
+from gi.repository import Gtk
 
 from .service import BaseService
 
 
-class ServiceWidgetBase(Gtk.Box):  # type: ignore
+class ServiceWidgetBase(Gtk.Box):
     """basclass for widget that need to be calling things from the service instance"""
 
     def __init__(self, service: BaseService, *args: Any, **kwargs: Any) -> None:
@@ -19,7 +19,7 @@ class ServiceWidgetBase(Gtk.Box):  # type: ignore
         super().__init__(*args, **kwargs)
 
 
-class ServiceWindowBase(Gtk.Window):  # type: ignore
+class ServiceWindowBase(Gtk.Window):
     """basclass for a window that needs to be calling things from the service instance"""
 
     def __init__(self, service: BaseService, *args: Any, **kwargs: Any) -> None:
